@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """Init file for pyprql.pandas.
 
 Examples
@@ -6,7 +5,7 @@ Examples
 import  pandas as pd
 import pyprql.pandas
 df = pd.DataFrame({})
-results_df = df.prql.query('from df | select [age,name,occupation] | filter age > 21')
+results_df = df.prql.query('select [age,name,occupation] | filter age > 21')
 
 """
 import pyprql.pandas_accessor.prql  # noqa: F401
